@@ -1,7 +1,7 @@
 package App::lcpan::Call;
 
 our $DATE = '2016-10-09'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -85,7 +85,7 @@ sub check_lcpan {
                     "($age_in_days), please refresh it first with ".
                     "'lcpan update'"];
     }
-    [200,"OK"];
+    $res;
 }
 
 1;
@@ -103,7 +103,7 @@ App::lcpan::Call - "Call" lcpan script
 
 =head1 VERSION
 
-This document describes version 0.10 of App::lcpan::Call (from Perl distribution App-lcpan-Call), released on 2016-10-09.
+This document describes version 0.11 of App::lcpan::Call (from Perl distribution App-lcpan-Call), released on 2016-10-09.
 
 =head1 FUNCTIONS
 
